k = 2*pi*1;
w = k*343;
L = 4.4;
x0 = 3.2;
x_up = 0:0.001:x0;
x_down = x0+0.001:0.001:L;
x = [x_up x_down];

% Optimal multiplicative factor for the secondary source 
ks = -1/cos(k*x0);

% Normalized pressure and particle velocity variables
Cnp = -j*exp(j*k*L);
Dnp = -j*exp(-j*k*L);
pp = Cnp*exp(-j*k*x)+Dnp*exp(j*k*x);
up = Cnp*exp(-j*k*x)-Dnp*exp(j*k*x);

Ans = ks*(-j*cos(k*(L-x0)));
Bns = ks*An;
Cns = ks*(-j*cos(k*x0)*exp(j*k*L));
Dns = ks*(-j*cos(k*x0)*exp(-j*k*L));

ps_up = Ans*exp(-j*k*x_up)+Bns*exp(j*k*x_up);
ps_down = Cns*exp(-j*k*x_down)+Dns*exp(j*k*x_down);
ps = [ps_up ps_down];

us_up = Ans*exp(-j*k*x_up)-Bns*exp(j*k*x_up);
us_down = Cns*exp(-j*k*x_down)-Dns*exp(j*k*x_down);
us = [us_up us_down];

t = 0;

figure
subplot(211)
hpp = plot(x,real(pp*exp(j*w*t)));
set(hpp,'EraseMode','xor');
grid
axis([0 L -4 4])
title('normalized p(x,t) (primary = blue, secondary = green, total = red)')
hold on
plot([0 0],[-4 4],'b--')
hps = plot(x,real(ps*exp(j*w*t)),'g');
set(hps,'EraseMode','xor');
plot(x0*[1 1],[-4 4],'g--')
hptot = plot(x,real(pp*exp(j*w*t))+real(ps*exp(j*w*t)),'r');
set(hptot,'EraseMode','xor','LineWidth',2);
hold off

subplot(212)
hup = plot(x,real(up*exp(j*w*t)));
set(hup,'EraseMode','xor');
grid
axis([0 L -4 4])
title('normalized u(x,t) (primary = blue, secondary = green, total = red)')
hold on
plot([0 0],[-4 4],'b--')
hus = plot(x,real(us*exp(j*w*t)),'g');
set(hus,'EraseMode','xor');
plot(x0*[1 1],[-4 4],'g--')
hutot = plot(x,real(up*exp(j*w*t))+real(us*exp(j*w*t)),'r');
set(hutot,'EraseMode','xor','LineWidth',2);
xlabel('CTRL-C to terminate')
hold off

while 1
   t = t+0.0001;
   set(hpp,'YData',real(pp*exp(j*w*t)));
   set(hps,'YData',real(ps*exp(j*w*t)));
   set(hptot,'YData',real(pp*exp(j*w*t))+real(ps*exp(j*w*t)));
   set(hup,'YData',real(up*exp(j*w*t)));
   set(hus,'YData',real(us*exp(j*w*t)));
   set(hutot,'YData',real(up*exp(j*w*t))+real(us*exp(j*w*t)));
   pause(0.03)
   drawnow
end
